Enum orzir_core::Value

source ·
pub enum Value {
    OpResult {
        self_ptr: ArenaPtr<Self>,
        ty: ArenaPtr<TyObj>,
        op: ArenaPtr<OpObj>,
        index: usize,
    },
    BlockArgument {
        self_ptr: ArenaPtr<Self>,
        ty: ArenaPtr<TyObj>,
        block: ArenaPtr<Block>,
        index: usize,
    },
}
An SSA value.

Variants



OpResult

The value is a result of an operation.

Fields

self_ptr: ArenaPtr<Self>

The self ptr.

ty: ArenaPtr<TyObj>

The type of the result.

op: ArenaPtr<OpObj>

The operation.

index: usize

The index of the result.



BlockArgument

The value is a block argument.

Fields

self_ptr: ArenaPtr<Self>

The self ptr.

ty: ArenaPtr<TyObj>

The type of the argument.

block: ArenaPtr<Block>

The block of the argument.

index: usize

The index of the argument.

Implementations

source

impl Value

source

pub fn new_op_result( ctx: &mut Context, ty: ArenaPtr<TyObj>, op: ArenaPtr<OpObj>, index: usize, name: Option<String> ) -> ArenaPtr<Value>

Create a new Value::OpResult.

If the name is not none, this will lookup for reserved arena ptr by the name.

source

pub fn new_block_argument( ctx: &mut Context, ty: ArenaPtr<TyObj>, block: ArenaPtr<Block>, index: usize, name: Option<String> ) -> ArenaPtr<Value>

Create a new Value::BlockArgument.

If the name is not none, this will lookup for reserved arena ptr by the name.

source

pub fn name(&self, ctx: &Context) -> String

Get the name of the value.

This will lookup the name by the self ptr. If the name is not set, the name manager will allocate a new name.

source

pub fn parent_region(&self, ctx: &Context) -> ArenaPtr<Region>

Get the parent region of the value.

source

pub fn ty(&self, _: &Context) -> ArenaPtr<TyObj>