Struct orzir_core::ApInt

source ·
pub struct ApInt { /* private fields */ }
An arbitrary precision integer with signedless semantics.

Implementations

source

impl ApInt

source

pub fn zero(width: usize) -> Self

Create a 0 with given width.

source

pub fn is_zero(&self) -> bool

Check if the integer is zero.

source

pub fn one(width: usize) -> Self

Create a 1 with given width.

source

pub fn is_one(&self) -> bool

Check if the integer is one.

source

pub fn width(&self) -> usize

Get the width of the integer.

source

pub fn inplace_bitor(&mut self, other: &Self)

Inplace bitwise or operation.

source

pub fn inplace_bitand(&mut self, other: &Self)

Inplace bitwise and operation.

source

pub fn inplace_bitxor(&mut self, other: &Self)

Inplace bitwise xor operation.

source

pub fn inplace_bitnot(&mut self)

Inplace bitwise not operation.

source

pub fn zeroext(&mut self, width: usize)

Inplace addition operation.

source

pub fn signext(&mut self, width: usize)

Inplace addition operation.

source

pub fn into_signext(self, width: usize) -> Self

Consumes the integer and zero extends it.

source

pub fn into_zeroext(self, width: usize) -> Self

Consumes the integer and zero extends it.

source

pub fn truncate(&mut self, width: usize) -> Self

Inplace addition operation.

source

pub fn into_truncated(self, width: usize) -> (Self, Self)

Consumes the integer and truncates it.

source

pub fn inplace_add(&mut self, rhs: &Self) -> bool

Inplace addition and return the carry.

source

pub fn inplace_sub(&mut self, rhs: &Self) -> bool

Inplace subtraction and return the borrow.

source

pub fn inplace_widening_shl(&mut self, shamt: usize)

Inplace shift left and widen the integer.

source

pub fn inplace_carrying_shl(&mut self, shamt: usize) -> Self

Inplace shift left and return the overflow.

source

pub fn highest_bit(&self) -> bool

Get the highest bit of the integer.

source

pub fn all_ones(width: usize) -> Self

Get the lowest bit of the integer.

source

pub fn inplace_neg(&mut self)

Inplace negation.

source

pub fn inplace_abs(&mut self) -> bool

Inplace absolute value and return the sign.

source

pub fn into_abs(self) -> (Self, bool)

Consumes the integer and return the absolute value and the sign.

source

pub fn inplace_widening_umul_chunk(&mut self, chunk: u64)

Inplace widening unsigned multiplication by a chunk.

This operation widen the integer by one chunk width.

source

pub fn shrink_to_fit(&mut self)

Shrinks the integer to minimum width.

source

pub fn into_shrunk(self) -> Self

Consumes the integer and return the shrunk integer.

source

pub fn inplace_carrying_umul_chunk(&mut self, chunk: u64) -> Self

Inplace carrying unsigned multiplication by a chunk.

source

pub fn inplace_widening_umul(&mut self, rhs: &Self)

Inplace widening unsigned multiplication.

source

pub fn inplace_widening_smul(&mut self, rhs: &Self)

Inplace widening signed multiplication.

source

pub fn inplace_carrying_umul(&mut self, rhs: &Self) -> Self

Inplace carrying signed multiplication, return the overflow.

source

pub fn inplace_carrying_smul(&mut self, rhs: &Self) -> Self

Inplace carrying signed multiplication, return the overflow.

source

pub fn inplace_lshr(&mut self, shamt: usize) -> Self

Inplace logical shift right and return the discarded bits.

source

pub fn inplace_ashr(&mut self, shamt: usize) -> Self

Inplace arithmetic shift right and return the discarded bits.

source

pub fn inplace_udiv(&mut self, divisor: &Self) -> Self

Unsigned division and return the remainder.

source

pub fn inplace_sdiv(&mut self, divisor: &Self) -> Self

Signed division and return the remainder.