Struct orzir_core::Block

source ·
pub struct Block { /* private fields */ }
The block in the region.

Implementations

source

impl Block

source

pub fn new( ctx: &mut Context, is_entry: bool, parent_region: ArenaPtr<Region>, name: Option<String> ) -> ArenaPtr<Block>

Create a new block.

source

pub fn layout(&self) -> &List<ArenaPtr<OpObj>, OpNode>

Get the layout of operations in the block.

source

pub fn layout_mut(&mut self) -> &mut List<ArenaPtr<OpObj>, OpNode>

Get the mutable layout of operations in the block.

source

pub fn name(&self, ctx: &Context) -> String

Get the name of the block.

This will allocate a new name if the block does not have one.

source

pub fn set_name( &self, ctx: &Context, name: String ) -> Result<(), NameAllocDuplicatedErr>

Set the name of the block.

source

pub fn set_arg( &mut self, index: usize, arg: ArenaPtr<Value> ) -> Option<ArenaPtr<Value>>

Set the arguments of the block by the given index.

source

pub fn num_args(&self) -> usize

Get the number of arguments of the block.

source

pub fn args(&self) -> &[ArenaPtr<Value>]

Get the arguments of the block.

source

pub fn is_entry(&self) -> bool

Test if the block is an entry block.

source

pub fn parent_region(&self) -> ArenaPtr<Region>

Get the parent region of the block.