Struct orzir_core::Dialect

source ·
pub struct Dialect { /* private fields */ }
A dialect.

Dialects define the operations and types that are available in a specific language. This is the same as dialects in the MLIR, which make it possible to extend the framework with new operations and types.

Implementations

source

impl Dialect

source

pub fn new(mnemonic: MnemonicSegment) -> Self

Create an empty dialect from a mnemonic.

source

pub fn mnemonic(&self) -> MnemonicSegment

Get the mnemonic of the dialect.

source

pub fn add_op(&mut self, mnemonic: Mnemonic, parse_fn: OpParseFn)

Add an operation and its parse function.

source

pub fn add_ty(&mut self, mnemonic: Mnemonic, parse_fn: TyParseFn)

Add a type and its parse function.

source

pub fn get_op_parse_fn(&self, mnemonic: &Mnemonic) -> Option<&OpParseFn>

Get the operation parse function.

source

pub fn get_ty_parse_fn(&self, mnemonic: &Mnemonic) -> Option<&TyParseFn>

Get the type parse function.