Struct orzir_core::Mnemonic

source ·
pub struct Mnemonic { /* private fields */ }
A mnemonic.

A mnemonic is in the format of dialect.op/attr/ty/.... Both the primary part and the secondary part are mnemonic segments. The primary part is stored in the context, and the secondary part is stored in the dialect.

If there are more than two parts in the mnemonic, the first dot will be used to split.

Implementations

source

impl Mnemonic

source

pub fn new(primary: &str, secondary: &str) -> Self

Create a new mnemonic.

source

pub fn primary(&self) -> &MnemonicSegment

Get the primary part of the mnemonic.

source

pub fn secondary(&self) -> &MnemonicSegment

Get the secondary part of the mnemonic.