Struct orzir_core::OpObj

source ·
pub struct OpObj(/* private fields */);

Implementations

source

impl OpObj

source

pub fn is_a<T: Op>(&self) -> bool

Check if the type object is a concrete type.

source

pub fn as_a<T: Op>(&self) -> Option<&T>

Try to downcast the type object to a concrete type.

source

pub fn impls<T: ?Sized + 'static>(&self, ctx: &Context) -> bool

Check if the type object implements a trait.

source

pub fn cast_ref<T: ?Sized + 'static>(&self, ctx: &Context) -> Option<&T>

Try to cast the type object to another trait.

source

pub fn cast_mut<T: ?Sized + 'static>(&mut self, ctx: &Context) -> Option<&mut T>