Struct orzir_core::ParseState

source ·
pub struct ParseState<'a> {
    pub stream: TokenStream<'a>,
    /* private fields */
}
The parse state for the parser.

This is used to store the current state of the parser, including the stream, the stack of ops, regions, blocks, region info, and result names.

Fields

stream: TokenStream<'a>

Implementations

source

impl<'a> ParseState<'a>

source

pub fn new(stream: TokenStream<'a>) -> Self

source

pub fn enter_op_from(&mut self, block: ArenaPtr<Block>)

Enter a new op from the current block.

source

pub fn exit_op(&mut self)

Exit the current op.

source

pub fn enter_component_from(&mut self, op: ArenaPtr<OpObj>)

Enter an arbitrary operation component.

source

pub fn exit_component(&mut self)

Exit an arbitrary operation component.

source

pub fn enter_region_with(&mut self, kind: RegionKind, index: usize)

Enter a new region from the current op, with the region kind and index.

source

pub fn exit_region(&mut self)

Exit the current region.

source

pub fn enter_block_from(&mut self, region: ArenaPtr<Region>)

Enter a new block from the current region.

source

pub fn exit_block(&mut self)

Exit the current block.

source

pub fn curr_op(&self) -> ArenaPtr<OpObj>

Get the current op.

source

pub fn curr_region(&self) -> ArenaPtr<Region>

Get the current region.

source

pub fn curr_block(&self) -> Option<ArenaPtr<Block>>

Get the current block.

source

pub fn curr_region_info(&self) -> (RegionKind, usize)

Get the current region kind and index.

source

pub fn pop_result_names(&mut self) -> Vec<Token>

Get and pop the current result names.

source

pub fn push_result_names(&mut self, names: Vec<Token>)

Push a new series of result name.