Struct orzir_core::TokenStream

source ·
pub struct TokenStream<'a> { /* private fields */ }
A tokenizer for the IR program.

This is used for the Parse trait to parse the IR program.

Implementations

source

impl<'a> TokenStream<'a>

source

pub fn new(slice: &'a str) -> Self

source

pub fn checkpoint(&mut self)

Set a checkpoint.

source

pub fn commit(&mut self)

Pop the last checkpoint and commit the changes.

source

pub fn rollback(&mut self)

Rollback to the last checkpoint.

This will also reset the buffered token.

source

pub fn peek(&mut self) -> ParseResult<&Token>

Peek the next token.

This will return the buffered token if exists, otherwise buffer the next

source

pub fn consume(&mut self) -> ParseResult<Token>

Consume the next token.

source

pub fn consume_if(&mut self, kind: TokenKind) -> ParseResult<Option<Token>>

source

pub fn expect(&mut self, kind: TokenKind) -> ParseResult<()>

source

pub fn curr_pos(&mut self) -> ParseResult<Pos>