Struct orzir_core::TyObj

source ·
pub struct TyObj(/* private fields */);

Implementations

source

impl TyObj

source

pub fn is_a<T: Ty>(&self) -> bool

Check if the type object is a concrete type.

source

pub fn as_a<T: Ty>(&self) -> Option<&T>

Try to downcast the type object to a concrete type.

source

pub fn impls<T: ?Sized + 'static>(&self, ctx: &Context) -> bool

Check if the type object implements a trait.

source

pub fn cast_ref<T: ?Sized + 'static>(&self, ctx: &Context) -> Option<&T>

Try to cast the type object to another trait.