Trait orzir_core::Ty

source ·
pub trait Ty: Downcast + GetUniqueArenaHash + Print + Verify {
    // Required methods
    fn mnemonic(&self) -> Mnemonic;
    fn mnemonic_static() -> Mnemonic
       where Self: Sized;
    fn eq(&self, other: &dyn Ty) -> bool;
    fn register(ctx: &mut Context, parse_fn: TyParseFn)
       where Self: Sized;
}

Required Methods

source

fn mnemonic(&self) -> Mnemonic

Get the mnemonic of the type.

source

fn mnemonic_static() -> Mnemonic
where Self: Sized,

Get the mnemonic of the type statically.

source

fn eq(&self, other: &dyn Ty) -> bool

Check if the type is equal to another type.

source

fn register(ctx: &mut Context, parse_fn: TyParseFn)
where Self: Sized,

Implementations

source

impl dyn Ty

source

pub fn is<__T: Ty>(&self) -> bool

Returns true if the trait object wraps an object of type __T.

source

pub fn downcast<__T: Ty>(self: Box<Self>) -> Result<Box<__T>, Box<Self>>

Returns a boxed object from a boxed trait object if the underlying object is of type __T. Returns the original boxed trait if it isn’t.

source

pub fn downcast_rc<__T: Ty>(self: Rc<Self>) -> Result<Rc<__T>, Rc<Self>>

Returns an Rc-ed object from an Rc-ed trait object if the underlying object is of type __T. Returns the original Rc-ed trait if it isn’t.

source

pub fn downcast_ref<__T: Ty>(&self) -> Option<&__T>

Returns a reference to the object within the trait object if it is of type __T, or None if it isn’t.

source

pub fn downcast_mut<__T: Ty>(&mut self) -> Option<&mut __T>

Returns a mutable reference to the object within the trait object if it is of type __T, or None if it isn’t.