Enum orzir_core::TokenKind
source · pub enum TokenKind {
}Expand description
A token kind.
Variants
Char(char)
A character
For delimiters, only :, =, ,, ;, * and - are supported. And
for brackets, only (, ), {, }, [, ], <, > are supported.
^, %, !, @ will be used for block label, value name, type alias
and symbol name respectively if they are not followed by an identifier,
otherwise they will be treated as normal characters.
Arrow
->
BlockLabel(String)
A block label starting with ^.
ValueName(String)
A block name starting with %.
TyAlias(String)
A type alias starting with !.
This is the same with MLIR, but not used yet.
SymbolName(String)
A symbol name starting with @.
Tokenized(String)
Other tokenized string.
This represents contiguous alphanumeric or with _, . characters. And
if the string is quoted, there can be escape sequences. This may also
represent numbers, but the parsing process is up to the parser.
Eof
End of file.
AnyBlockLabel
The wildcard for block label
AnyValueName
The wildcard for value name
AnyTyAlias
The wildcard for type alias
AnySymbolName
The wildcard for symbol name
AnyTokenized
The wildcard for any tokenized string.
Implementations