Enum orzir_core::Value
source · pub enum Value {
OpResult {
self_ptr: ArenaPtr<Self>,
ty: ArenaPtr<TyObj>,
op: ArenaPtr<OpObj>,
index: usize,
},
BlockArgument {
self_ptr: ArenaPtr<Self>,
ty: ArenaPtr<TyObj>,
block: ArenaPtr<Block>,
index: usize,
},
}Expand description
An SSA value.
Variants
Implementations
sourceimpl Value
impl Value
sourcepub fn new_op_result(
ctx: &mut Context,
ty: ArenaPtr<TyObj>,
op: ArenaPtr<OpObj>,
index: usize,
name: Option<String>
) -> ArenaPtr<Value>
pub fn new_op_result( ctx: &mut Context, ty: ArenaPtr<TyObj>, op: ArenaPtr<OpObj>, index: usize, name: Option<String> ) -> ArenaPtr<Value>
Create a new Value::OpResult.
If the name is not none, this will lookup for reserved arena ptr by the name.
sourcepub fn new_block_argument(
ctx: &mut Context,
ty: ArenaPtr<TyObj>,
block: ArenaPtr<Block>,
index: usize,
name: Option<String>
) -> ArenaPtr<Value>
pub fn new_block_argument( ctx: &mut Context, ty: ArenaPtr<TyObj>, block: ArenaPtr<Block>, index: usize, name: Option<String> ) -> ArenaPtr<Value>
Create a new Value::BlockArgument.
If the name is not none, this will lookup for reserved arena ptr by the name.
sourcepub fn name(&self, ctx: &Context) -> String
pub fn name(&self, ctx: &Context) -> String
Get the name of the value.
This will lookup the name by the self ptr. If the name is not set, the name manager will allocate a new name.
sourcepub fn parent_region(&self, ctx: &Context) -> ArenaPtr<Region>
pub fn parent_region(&self, ctx: &Context) -> ArenaPtr<Region>
Get the parent region of the value.
pub fn ty(&self, _: &Context) -> ArenaPtr<TyObj>