Struct orzir_core::Block
source · pub struct Block { /* private fields */ }Expand description
The block in the region.
Implementations
sourceimpl Block
impl Block
sourcepub fn new(
ctx: &mut Context,
is_entry: bool,
parent_region: ArenaPtr<Region>,
name: Option<String>
) -> ArenaPtr<Block>
pub fn new( ctx: &mut Context, is_entry: bool, parent_region: ArenaPtr<Region>, name: Option<String> ) -> ArenaPtr<Block>
Create a new block.
sourcepub fn layout(&self) -> &List<ArenaPtr<OpObj>, OpNode>
pub fn layout(&self) -> &List<ArenaPtr<OpObj>, OpNode>
Get the layout of operations in the block.
sourcepub fn layout_mut(&mut self) -> &mut List<ArenaPtr<OpObj>, OpNode>
pub fn layout_mut(&mut self) -> &mut List<ArenaPtr<OpObj>, OpNode>
Get the mutable layout of operations in the block.
sourcepub fn name(&self, ctx: &Context) -> String
pub fn name(&self, ctx: &Context) -> String
Get the name of the block.
This will allocate a new name if the block does not have one.
sourcepub fn set_name(
&self,
ctx: &Context,
name: String
) -> Result<(), NameAllocDuplicatedErr>
pub fn set_name( &self, ctx: &Context, name: String ) -> Result<(), NameAllocDuplicatedErr>
Set the name of the block.
sourcepub fn set_arg(
&mut self,
index: usize,
arg: ArenaPtr<Value>
) -> Option<ArenaPtr<Value>>
pub fn set_arg( &mut self, index: usize, arg: ArenaPtr<Value> ) -> Option<ArenaPtr<Value>>
Set the arguments of the block by the given index.
sourcepub fn parent_region(&self) -> ArenaPtr<Region>
pub fn parent_region(&self) -> ArenaPtr<Region>
Get the parent region of the block.