Struct orzir_core::Caster
source · pub struct Caster<T: ?Sized + 'static> { /* private fields */ }Expand description
A caster for trait-to-trait casting.
Given a trait object and the dyn Target type, first upcast it to dyn Any, then get the caster using the concrete type id fetched from the Any
object, and the type id of the concrete caster Caster<dyn Target>. The
just get the caster from the storage and do the cast.
The caster functions can be simply implemented by downcasting the Any
object to the concrete type and then just let rust do the rest type
checking.
Example
A caster can be implemented like this:
ⓘ
let caster = Caster::<dyn Target> {
cast_ref: |any| any.downcast_ref::<Concrete>().unwrap() as &dyn Target,
cast_mut: |any| any.downcast_mut::<Concrete>().unwrap() as &mut dyn Target,
}Implementations