Struct orzir_core::Dialect
source · pub struct Dialect { /* private fields */ }Expand description
A dialect.
Dialects define the operations and types that are available in a specific language. This is the same as dialects in the MLIR, which make it possible to extend the framework with new operations and types.
Implementations
sourceimpl Dialect
impl Dialect
sourcepub fn new(mnemonic: MnemonicSegment) -> Self
pub fn new(mnemonic: MnemonicSegment) -> Self
Create an empty dialect from a mnemonic.
sourcepub fn mnemonic(&self) -> MnemonicSegment
pub fn mnemonic(&self) -> MnemonicSegment
Get the mnemonic of the dialect.
sourcepub fn add_op(&mut self, mnemonic: Mnemonic, parse_fn: OpParseFn)
pub fn add_op(&mut self, mnemonic: Mnemonic, parse_fn: OpParseFn)
Add an operation and its parse function.
sourcepub fn add_ty(&mut self, mnemonic: Mnemonic, parse_fn: TyParseFn)
pub fn add_ty(&mut self, mnemonic: Mnemonic, parse_fn: TyParseFn)
Add a type and its parse function.
sourcepub fn get_op_parse_fn(&self, mnemonic: &Mnemonic) -> Option<&OpParseFn>
pub fn get_op_parse_fn(&self, mnemonic: &Mnemonic) -> Option<&OpParseFn>
Get the operation parse function.
sourcepub fn get_ty_parse_fn(&self, mnemonic: &Mnemonic) -> Option<&TyParseFn>
pub fn get_ty_parse_fn(&self, mnemonic: &Mnemonic) -> Option<&TyParseFn>
Get the type parse function.