Struct orzir_core::Mnemonic
source · pub struct Mnemonic { /* private fields */ }Expand description
A mnemonic.
A mnemonic is in the format of dialect.op/attr/ty/....
Both the primary part and the secondary part are mnemonic segments.
The primary part is stored in the context, and the secondary part is stored
in the dialect.
If there are more than two parts in the mnemonic, the first dot will be used to split.
Implementations