Struct orzir_core::TokenStream
source · pub struct TokenStream<'a> { /* private fields */ }Expand description
A tokenizer for the IR program.
This is used for the Parse trait to parse the IR program.
Implementations
sourceimpl<'a> TokenStream<'a>
impl<'a> TokenStream<'a>
pub fn new(slice: &'a str) -> Self
sourcepub fn checkpoint(&mut self)
pub fn checkpoint(&mut self)
Set a checkpoint.
sourcepub fn rollback(&mut self)
pub fn rollback(&mut self)
Rollback to the last checkpoint.
This will also reset the buffered token.
sourcepub fn peek(&mut self) -> ParseResult<&Token>
pub fn peek(&mut self) -> ParseResult<&Token>
Peek the next token.
This will return the buffered token if exists, otherwise buffer the next
sourcepub fn consume(&mut self) -> ParseResult<Token>
pub fn consume(&mut self) -> ParseResult<Token>
Consume the next token.
pub fn consume_if(&mut self, kind: TokenKind) -> ParseResult<Option<Token>>
pub fn expect(&mut self, kind: TokenKind) -> ParseResult<()>
pub fn curr_pos(&mut self) -> ParseResult<Pos>