Trait orzir_core::Ty
source · pub trait Ty: Downcast + GetUniqueArenaHash + Print + Verify {
// Required methods
fn mnemonic(&self) -> Mnemonic;
fn mnemonic_static() -> Mnemonic
where Self: Sized;
fn eq(&self, other: &dyn Ty) -> bool;
fn register(ctx: &mut Context, parse_fn: TyParseFn)
where Self: Sized;
}Required Methods
sourcefn mnemonic_static() -> Mnemonicwhere
Self: Sized,
fn mnemonic_static() -> Mnemonicwhere
Self: Sized,
Get the mnemonic of the type statically.
fn register(ctx: &mut Context, parse_fn: TyParseFn)where
Self: Sized,
Implementations
sourceimpl dyn Ty
impl dyn Ty
sourcepub fn is<__T: Ty>(&self) -> bool
pub fn is<__T: Ty>(&self) -> bool
Returns true if the trait object wraps an object of type __T.
sourcepub fn downcast<__T: Ty>(self: Box<Self>) -> Result<Box<__T>, Box<Self>>
pub fn downcast<__T: Ty>(self: Box<Self>) -> Result<Box<__T>, Box<Self>>
Returns a boxed object from a boxed trait object if the underlying object is of type
__T. Returns the original boxed trait if it isn’t.
sourcepub fn downcast_rc<__T: Ty>(self: Rc<Self>) -> Result<Rc<__T>, Rc<Self>>
pub fn downcast_rc<__T: Ty>(self: Rc<Self>) -> Result<Rc<__T>, Rc<Self>>
Returns an Rc-ed object from an Rc-ed trait object if the underlying object is of
type __T. Returns the original Rc-ed trait if it isn’t.
sourcepub fn downcast_ref<__T: Ty>(&self) -> Option<&__T>
pub fn downcast_ref<__T: Ty>(&self) -> Option<&__T>
Returns a reference to the object within the trait object if it is of type __T, or
None if it isn’t.
sourcepub fn downcast_mut<__T: Ty>(&mut self) -> Option<&mut __T>
pub fn downcast_mut<__T: Ty>(&mut self) -> Option<&mut __T>
Returns a mutable reference to the object within the trait object if it is of type
__T, or None if it isn’t.